Package: emdbook
Type: Package
Title: Support Functions and Data for "Ecological Models and Data"
Version: 1.3.14
LazyData: yes
Authors@R: c(person("Ben","Bolker",email="bolker@mcmaster.ca", role=c("aut","cre")),
	   person("Sang Woo","Park",role="ctb"),
	   person("James","Vonesh",role="dtc"),
	   person("Jacqueline","Wilson",role="dtc"),
	   person("Russ","Schmitt",role="dtc"),
	   person("Sally","Holbrook",role="dtc"),
	   person("James D.","Thomson",role="dtc"),
	   person("R. Scot","Duncan",role="dtc")
	   )
Description: Auxiliary functions and data sets for "Ecological Models and Data", a book presenting maximum likelihood estimation and related topics for ecologists (ISBN 978-0-691-12522-0).
Suggests: R2jags, ellipse, SuppDists, numDeriv, testthat, rgl
Imports: MASS, lattice, plyr, coda, bbmle
License: GPL
URL: https://math.mcmaster.ca/bolker/emdbook
NeedsCompilation: no
Packaged: 2025-07-23 13:42:20 UTC; bolker
Author: Ben Bolker [aut, cre],
  Sang Woo Park [ctb],
  James Vonesh [dtc],
  Jacqueline Wilson [dtc],
  Russ Schmitt [dtc],
  Sally Holbrook [dtc],
  James D. Thomson [dtc],
  R. Scot Duncan [dtc]
Maintainer: Ben Bolker <bolker@mcmaster.ca>
Repository: CRAN
Date/Publication: 2025-07-23 14:50:02 UTC
