\name{emdbook-package}
\alias{emdbook-package}
\alias{emdbook}
\docType{package}
\title{
  \packageTitle{emdbook}
}
\description{
  \packageDescription{emdbook}
}
\references{
  \cite{Bolker, Benjamin M. Ecological Models and Data in R. Princeton University Press, 2008}
}
\keyword{ package }

